==> jetburn-1.0.tar.gz: jetburn-1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Setup script for jetburn
Install jetburn with:
python setup.py install
"""

# Source code meta data
__author__ = 'Dalwar Hossain'
__email__ = 'dalwar.hossain@protonmail.com'

# Import python libraries
import os
import sys
from setuptools import setup


# Check if enough parameter has been given to install or not
if sys.argv[-1] == 'setup.py':
    print("To install, run 'python setup.py install'")
    print()


# Check python version before installing
if sys.version_info[:2] < (2, 7):
    print("JETBURN requires Python 2.7 or later (%d.%d detected)." % sys.version_info[:2])
    sys.exit(-1)


# Get version and release for this package
package_name = 'jetburn'
release_file = os.path.join(package_name, '_release_info.py')
release_info = {}
with open(release_file, 'rb') as rf:
    exec(rf.read(), release_info)


# Read the README.md file for long description
def readme():
    with open('README.rst') as f:
        return f.read()


# Standard boilerplate to run this script
if __name__ == "__main__":
    setup(
        name=package_name,
        version=release_info['__version__'],
        maintainer='Dalwar Hossain',
        maintainer_email='dalwar.hossain@protonmail.com',
        author=release_info['__author__'],
        author_email=release_info['__email__'],
        description='jetburn - Airline tickets explorer program',
        keywords=['jetburn', 'airlines', 'tickets', 'fares'],
        long_description=readme(),
        license='LGPL-3.0',
        platforms=['Linux', 'Mac OSX', 'Windows', 'Unix'],
        url='https://github.com/dharif23/jetburn',
        download_url='https://github.com/dharif23/jetburn',
        classifiers=[
            'Development Status :: 4 - Beta',
            'Intended Audience :: Developers',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved :: MIT License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3.7',
            'Topic :: Software Development :: Libraries :: Python Modules'],
        packages=['jetburn'],
        entry_points={
            'console_scripts': ['jetburn=jetburn.flight_control:jetburn_cli'],
        },
        include_package_data=True,
        install_requires=['pip>=18.0',
                          'pyrainbowterm>=1.0',
                          'setuptools>=40.1.0',
                          'six>=1.10.0',
                          'wheel>=0.31.1',
                          'pyfiglet>=0.7.6',
                          'inquirer>=2.5.1',
                          'tabulate>=0.8.2',
                          'datapackage>=1.5.1',
                          'requests>=2.20.0',
                          'sphinx>=1.7.1',
                          'recommonmark >=0.4.0',
                          'sphinx_rtd_theme>=0.4.1',
                          ],
        test_suite='nose.collector',
        tests_require=['nose>=1.3.7', 'nose-cover3>=0.1.0'],
        zip_safe=False,
    )

==> jetburn-1.2.tar.gz: jetburn-1.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Setup script for jetburn
Install jetburn with:
python setup.py install
"""

# Source code meta data
__author__ = 'Dalwar Hossain'
__email__ = 'dalwar.hossain@protonmail.com'

# Import python libraries
import os
import sys
from setuptools import setup


# Check if enough parameter has been given to install or not
if sys.argv[-1] == 'setup.py':
    print("To install, run 'python setup.py install'")
    print()


# Check python version before installing
if sys.version_info[:2] < (2, 7):
    print("JETBURN requires Python 2.7 or later (%d.%d detected)." % sys.version_info[:2])
    sys.exit(-1)


# Get version and release for this package
package_name = 'jetburn'
release_file = os.path.join(package_name, '_release_info.py')
release_info = {}
with open(release_file, 'rb') as rf:
    exec(rf.read(), release_info)


# Read the README.md file for long description
def readme():
    with open('README.rst') as f:
        return f.read()


# Standard boilerplate to run this script
if __name__ == "__main__":
    setup(
        name=package_name,
        version=release_info['__version__'] + '.' + release_info['__release__'],
        maintainer='Dalwar Hossain',
        maintainer_email='dalwar.hossain@protonmail.com',
        author=release_info['__author__'],
        author_email=release_info['__email__'],
        description='jetburn - Airline tickets explorer program',
        keywords=['jetburn', 'airlines', 'tickets', 'fares'],
        long_description=readme(),
        license='LGPL-3.0',
        platforms=['Linux', 'Mac OSX', 'Windows', 'Unix'],
        url='https://github.com/dharif23/jetburn',
        download_url='https://github.com/dharif23/jetburn',
        classifiers=[
            'Development Status :: 4 - Beta',
            'Intended Audience :: Developers',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved :: MIT License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3.7',
            'Topic :: Software Development :: Libraries :: Python Modules'],
        packages=['jetburn'],
        entry_points={
            'console_scripts': ['jetburn=jetburn.flight_control:jetburn_cli'],
        },
        include_package_data=True,
        install_requires=['pip>=18.0',
                          'pyrainbowterm>=1.0',
                          'setuptools>=40.1.0',
                          'six>=1.10.0',
                          'wheel>=0.31.1',
                          'pyfiglet>=0.7.6',
                          'inquirer>=2.5.1',
                          'tabulate>=0.8.2',
                          'datapackage>=1.5.1',
                          'requests>=2.20.0',
                          'sphinx>=1.7.1',
                          'recommonmark >=0.4.0',
                          'sphinx_rtd_theme>=0.4.1',
                          ],
        test_suite='nose.collector',
        tests_require=['nose>=1.3.7', 'nose-cover3>=0.1.0'],
        zip_safe=False,
    )
